pub fn in_range_max(offset: u64, len: u64, max: u64) -> boolExpand description
Returns true if the range [offset, offset + len) is fully inside [0, max).
Returns false on arithmetic overflow or if out of bounds.
pub fn in_range_max(offset: u64, len: u64, max: u64) -> boolReturns true if the range [offset, offset + len) is fully inside [0, max).
Returns false on arithmetic overflow or if out of bounds.