pub fn in_range_min_max(offset: u64, len: u64, min: u64, max: u64) -> boolExpand description
Returns true if the range [offset, offset + len) is fully inside [min, max).
Returns false on arithmetic overflow, underflow, or if out of bounds.
pub fn in_range_min_max(offset: u64, len: u64, min: u64, max: u64) -> boolReturns true if the range [offset, offset + len) is fully inside [min, max).
Returns false on arithmetic overflow, underflow, or if out of bounds.